/*******************************************************************************
 * University of Illinois/NCSA
 * Open Source License
 *
 * Copyright (c) 2010 , NCSA.  All rights reserved.
 *
 * Developed by:
 * Cyberenvironments and Technologies (CET)
 * http://cet.ncsa.illinois.edu/
 *
 * National Center for Supercomputing Applications (NCSA)
 * http://www.ncsa.illinois.edu/
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal with the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimers.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimers in the
 *   documentation and/or other materials provided with the distribution.
 * - Neither the names of CET, University of Illinois/NCSA, nor the names
 *   of its contributors may be used to endorse or promote products
 *   derived from this Software without specific prior written permission.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 * IN NO EVENT SHALL THE CONTRIBUTORS OR COPYRIGHT HOLDERS BE LIABLE FOR
 * ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
 * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS WITH THE SOFTWARE.
 *******************************************************************************/
package edu.illinois.ncsa.paw.domain;

import java.util.Date;

import javax.persistence.Entity;

import edu.illinois.ncsa.domain.AbstractBean;

/**
 * Bean class for storing x509 certificates
 * 
 * @author cnavarro
 * 
 */
@Entity(name = "X509Certificate")
public class X509Certificate extends AbstractBean {

    /** Used for serialization of object */
    private static final long serialVersionUID = 2915764192814982867L;

    /** x509 Credential */
    private String            credential       = null;
    /** Date the credential expires */
    private Date              expirationDate;

    /**
     * Create new instance of the X509CertificateBean
     */
    public X509Certificate() {}

    /**
     * Return the x509 credential
     * 
     * @return the x509 credential
     */
    public String getCredential() {
        return credential;
    }

    /**
     * Sets the credential associated with this bean
     * 
     * @param credential
     *            sets the credential of the bean
     */
    public void setCredential(String credential) {
        this.credential = credential;
    }

    /**
     * Sets the expiration date of the credential
     * 
     * @param expirationDate
     *            sets the expiration date of the credential
     */
    public void setExpirationDate(Date expirationDate) {
        this.expirationDate = expirationDate;
    }

    /**
     * Return the expiration date of the credential
     * 
     * @return the expiration date of the credential
     */
    public Date getExpirationDate() {
        return expirationDate;
    }

}
